diff --git a/avplay.c b/avplay.c
index 93a0e1b5a8168819552b12a09511c03c1f521183..58db59639d2a676bfb890f1684bca75ba0fb5bed 100644
--- a/avplay.c
+++ b/avplay.c
@@ -2997,7 +2997,7 @@ static const OptionDef options[] = {
 #endif
     { "rdftspeed", OPT_INT | HAS_ARG| OPT_AUDIO | OPT_EXPERT, {(void*)&rdftspeed}, "rdft speed", "msecs" },
     { "default", HAS_ARG | OPT_AUDIO | OPT_VIDEO | OPT_EXPERT, {(void*)opt_default}, "generic catch all option", "" },
-    { "i", 0, {NULL}, "ffmpeg compatibility dummy option", ""},
+    { "i", 0, {NULL}, "avconv compatibility dummy option", ""},
     { NULL, },
 };
 
diff --git a/libavcodec/adxenc.c b/libavcodec/adxenc.c
index 296ccbd58aa3b266d75d98d0fd8a2e50eb4dd838..61ba07a35d50d213996188c46c531c4b60f7f7a4 100644
--- a/libavcodec/adxenc.c
+++ b/libavcodec/adxenc.c
@@ -145,7 +145,7 @@ static int adx_encode_frame(AVCodecContext *avctx,
 
 /*
     input data size =
-    ffmpeg.c: do_audio_out()
+    avconv.c:do_audio_out()
     frame_bytes = enc->frame_size * 2 * enc->channels;
 */
 
diff --git a/libavformat/cutils.c b/libavformat/cutils.c
index 092aa8a1a99c56484ca1059188bad26ab143303a..f94442f1bdef2d305c5083a6568f8746684f6a87 100644
--- a/libavformat/cutils.c
+++ b/libavformat/cutils.c
@@ -24,7 +24,7 @@
 /* add one element to a dynamic array */
 void ff_dynarray_add(intptr_t **tab_ptr, int *nb_ptr, intptr_t elem)
 {
-    /* see similar ffmpeg.c:grow_array() */
+    /* see similar avconv.c:grow_array() */
     int nb, nb_alloc;
     intptr_t *tab;
 
diff --git a/libavformat/http.c b/libavformat/http.c
index 10ec70fedd0b8f28f4306042d6b684748cbb8591..1db9e82cc4e4dff511209a7fffab9055fc4129b5 100644
--- a/libavformat/http.c
+++ b/libavformat/http.c
@@ -1,5 +1,5 @@
 /*
- * HTTP protocol for ffmpeg client
+ * HTTP protocol for avconv client
  * Copyright (c) 2000, 2001 Fabrice Bellard
  *
  * This file is part of Libav.
@@ -31,7 +31,7 @@
 #include "url.h"
 #include "libavutil/opt.h"
 
-/* XXX: POST protocol is not completely implemented because ffmpeg uses
+/* XXX: POST protocol is not completely implemented because avconv uses
    only a subset of it. */
 
 /* used for protocol handling */
diff --git a/libavformat/movenc.h b/libavformat/movenc.h
index 39cdb39284eed84c6595a4e2a0b1ed01b1d17789..bddae459da3543efeb14e9557d69ff4053b9c905 100644
--- a/libavformat/movenc.h
+++ b/libavformat/movenc.h
@@ -35,7 +35,7 @@
 #define MODE_MOV  0x02
 #define MODE_3GP  0x04
 #define MODE_PSP  0x08 // example working PSP command line:
-// ffmpeg -i testinput.avi  -f psp -r 14.985 -s 320x240 -b 768 -ar 24000 -ab 32 M4V00001.MP4
+// avconv -i testinput.avi  -f psp -r 14.985 -s 320x240 -b 768 -ar 24000 -ab 32 M4V00001.MP4
 #define MODE_3G2  0x10
 #define MODE_IPOD 0x20
 
diff --git a/libavformat/nsvdec.c b/libavformat/nsvdec.c
index 84957c6a7ac4fbc018b03ff7e11fa04e45171870..d0fac9afb03c9ec327b8784f68585e97a8da4498 100644
--- a/libavformat/nsvdec.c
+++ b/libavformat/nsvdec.c
@@ -71,7 +71,11 @@
  * so the header seems to not be mandatory. (for streaming).
  *
  * index slice duration check (excepts nsvtrailer.nsv):
- * for f in [^n]*.nsv; do DUR="$(ffmpeg -i "$f" 2>/dev/null | grep 'NSVf duration' | cut -d ' ' -f 4)"; IC="$(ffmpeg -i "$f" 2>/dev/null | grep 'INDEX ENTRIES' | cut -d ' ' -f 2)"; echo "duration $DUR, slite time $(($DUR/$IC))"; done
+ * for f in [^n]*.nsv; do
+ *     DUR="$(avconv -i "$f" 2> /dev/null | grep 'NSVf duration' | cut -d ' ' -f 4)"
+ *     IC="$(avconv -i "$f" 2> /dev/null | grep 'INDEX ENTRIES' | cut -d ' ' -f 2)"
+ *     echo "duration $DUR, slite time $(($DUR/$IC))"
+ * done
  */
 
 /*
diff --git a/avserver.c b/avserver.c
index cb8f41f5091ee13a60eada94fe4e68ed0bec9ae8..fb719e245ff10e6332573e110ea4d6eb120e2983 100644
--- a/avserver.c
+++ b/avserver.c
@@ -223,8 +223,8 @@ typedef struct FFStream {
     char title[512];
     char copyright[512];
     char comment[512];
-    pid_t pid;  /* Of ffmpeg process */
-    time_t pid_start;  /* Of ffmpeg process */
+    pid_t pid;  /* of avconv process */
+    time_t pid_start;  /* of avconv process */
     char **child_argv;
     struct FFStream *next;
     unsigned bandwidth; /* bandwidth, in kbits/s */
@@ -474,7 +474,7 @@ static void start_children(FFStream *feed)
                     slash = pathname;
                 else
                     slash++;
-                strcpy(slash, "ffmpeg");
+                strcpy(slash, "avconv");
 
                 http_log("Launch commandline: ");
                 http_log("%s ", pathname);
diff --git a/libavcodec/libxvidff.c b/libavcodec/libxvidff.c
index 526969066df8b2636b272c97706f89cae025305f..d0f4ed39be2b4bcfa60fb5aee9242b8099eab294 100644
--- a/libavcodec/libxvidff.c
+++ b/libavcodec/libxvidff.c
@@ -137,7 +137,7 @@ static av_cold int xvid_encode_init(AVCodecContext *avctx)  {
     xvid_enc_create_t xvid_enc_create;
     xvid_enc_plugin_t plugins[7];
 
     /* Bring in VOP flags from ffmpeg command-line */
     x->vop_flags = XVID_VOP_HALFPEL; /* Bare minimum quality */
     if( xvid_flags & CODEC_FLAG_4MV )
         x->vop_flags |= XVID_VOP_INTER4V; /* Level 3 */
@@ -191,7 +191,7 @@ static av_cold int xvid_encode_init(AVCodecContext *avctx)  {
            break;
     }
 
     /* Bring in VOL flags from ffmpeg command-line */
     x->vol_flags = 0;
     if( xvid_flags & CODEC_FLAG_GMC ) {
         x->vol_flags |= XVID_VOL_GMC;
@@ -669,7 +669,7 @@ static int xvid_ff_2pass_create(xvid_plg_create_t * param,
     /* This is because we can safely prevent a buffer overflow */
     log[0] = 0;
     snprintf(log, BUFFER_REMAINING(log),
-        "# ffmpeg 2-pass log file, using xvid codec\n");
+        "# avconv 2-pass log file, using xvid codec\n");
     snprintf(BUFFER_CAT(log), BUFFER_REMAINING(log),
         "# Do not modify. libxvidcore version: %d.%d.%d\n\n",
         XVID_VERSION_MAJOR(XVID_VERSION),
@@ -137,7 +137,7 @@ static av_cold int xvid_encode_init(AVCodecContext *avctx)  {
     xvid_enc_plugin_t plugins[7];
 
-    /* Bring in VOP flags from ffmpeg command-line */
+    /* Bring in VOP flags from avconv command-line */
     x->vop_flags = XVID_VOP_HALFPEL; /* Bare minimum quality */
     if( xvid_flags & CODEC_FLAG_4MV )
@@ -191,7 +191,7 @@ static av_cold int xvid_encode_init(AVCodecContext *avctx)  {
     }
 
-    /* Bring in VOL flags from ffmpeg command-line */
+    /* Bring in VOL flags from avconv command-line */
     x->vol_flags = 0;
     if( xvid_flags & CODEC_FLAG_GMC ) {